fsds.pandemic package
=====================

.. automodule:: fsds.pandemic
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

fsds.pandemic.coronavirus\_functions module
-------------------------------------------

.. automodule:: fsds.pandemic.coronavirus_functions
   :members:
   :undoc-members:
   :show-inheritance:

fsds.pandemic.data\_acquisition module
--------------------------------------

.. automodule:: fsds.pandemic.data_acquisition
   :members:
   :undoc-members:
   :show-inheritance:

fsds.pandemic.legacy\_data\_acquisition module
----------------------------------------------

.. automodule:: fsds.pandemic.legacy_data_acquisition
   :members:
   :undoc-members:
   :show-inheritance:

fsds.pandemic.timeseries\_modeling module
-----------------------------------------

.. automodule:: fsds.pandemic.timeseries_modeling
   :members:
   :undoc-members:
   :show-inheritance:
